@@ -16,7 +16,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "mainwindow.h"
@@ -72,7 +72,7 @@ using namespace GraphTheory;
 
 MainWindow::MainWindow()
     : KXmlGuiWindow()
-    , m_currentProject(0)
+    , m_currentProject(nullptr)
     , m_kernel(new Kernel)
     , m_codeEditorWidget(new CodeEditorWidget(this))
     , m_graphEditorWidget(new GraphEditorWidget(this))
